@@ -58,7 +58,7 @@ def main(arguments: Optional[Sequence[str]] = None):
 
 def create_parser() -> argparse.ArgumentParser:
     parser = argparse.ArgumentParser(
-        description="Command Line Interface for AnnoFab", formatter_class=annofabcli.common.cli.PrettyHelpFormatter
+        description="Command Line Interface for Annofab", formatter_class=annofabcli.common.cli.PrettyHelpFormatter
     )
     parser.add_argument("--version", action="version", version=f"annofabcli {annofabcli.__version__}")
     parser.set_defaults(command_help=parser.print_help)
