@@ -56,7 +56,7 @@ class ListOutOfRangeAnnotationForMovieMain:
 
     def create_dataframe(
         self,
-        proejct_id: str,
+        project_id: str,
         task_list: List[Dict[str, Any]],
         input_data_list: List[Dict[str, Any]],
         annotation_zip: Optional[Path],
@@ -67,7 +67,7 @@ class ListOutOfRangeAnnotationForMovieMain:
                 task["worktime_hour"] = _millisecond_to_hour(task["work_time_span"])
                 task["input_data_id"] = task["input_data_id_list"][0]
                 annotation, _ = self.service.api.get_editor_annotation(
-                    proejct_id, task["task_id"], task["input_data_id"]
+                    project_id, task["task_id"], task["input_data_id"]
                 )
                 max_seconds = self.get_max_seconds_for_webapi(annotation)
                 task["max_begin_second"] = max_seconds[0]
@@ -152,10 +152,10 @@ class ListOutOfRangeAnnotationForMovieMain:
         loop = asyncio.get_event_loop()
         loop.run_until_complete(gather)
 
-        with input_data_json_path.open() as f:
+        with input_data_json_path.open(encoding="utf-8") as f:
             input_data_list = json.load(f)
 
-        with task_json_path.open() as f:
+        with task_json_path.open(encoding="utf-8") as f:
             task_list = json.load(f)
             if task_id_list is not None:
                 task_list = self.filter_task_list(task_list, task_id_list)
