@@ -32,7 +32,7 @@ from annofabcli.statistics.linegraph import (
 logger = logging.getLogger(__name__)
 
 
-class AbstractRoleProductivityPerDate(abc.ABC):
+class AbstractPhaseProductivityPerDate(abc.ABC):
     """ロールごとの日ごとの生産性に関する情報を格納する抽象クラス"""
 
     PLOT_WIDTH = 1200
@@ -47,29 +47,29 @@ class AbstractRoleProductivityPerDate(abc.ABC):
             return False
         return True
 
-    @staticmethod
+    @classmethod
     @abc.abstractmethod
-    def from_df_task(df_task: pandas.DataFrame) -> AbstractRoleProductivityPerDate:
-        pass
+    def from_df_task(cls, df_task: pandas.DataFrame) -> AbstractPhaseProductivityPerDate:
+        raise NotImplementedError()
 
     @abc.abstractmethod
     def to_csv(self, output_file: Path):
-        pass
+        raise NotImplementedError()
 
     @abc.abstractmethod
     def plot_input_data_metrics(self, output_file: Path, target_user_id_list: Optional[list[str]] = None):
-        pass
+        raise NotImplementedError()
 
     @abc.abstractmethod
     def plot_annotation_metrics(self, output_file: Path, target_user_id_list: Optional[list[str]] = None):
-        pass
+        raise NotImplementedError()
 
 
-class AnnotatorProductivityPerDate(AbstractRoleProductivityPerDate):
+class AnnotatorProductivityPerDate(AbstractPhaseProductivityPerDate):
     """教師付開始日ごとの教師付者の生産性に関する情報"""
 
-    @staticmethod
-    def from_df_task(df_task: pandas.DataFrame) -> AnnotatorProductivityPerDate:
+    @classmethod
+    def from_df_task(cls, df_task: pandas.DataFrame) -> AnnotatorProductivityPerDate:
         """
         日毎、ユーザごとの情報を出力する。
 
@@ -98,11 +98,11 @@ class AnnotatorProductivityPerDate(AbstractRoleProductivityPerDate):
                 "annotation_worktime_hour",
                 "inspection_worktime_hour",
                 "acceptance_worktime_hour",
-                "sum_worktime_hour",
+                "worktime_hour",
                 "task_count",
                 "input_data_count",
                 "annotation_count",
-                "inspection_count",
+                "inspection_comment_count",
             ]
         ].sum()
 
@@ -113,10 +113,14 @@ class AnnotatorProductivityPerDate(AbstractRoleProductivityPerDate):
                     sum_df[numerator_column] / sum_df[denominator_column]
                 )
 
-        sum_df["inspection_count/annotation_count"] = sum_df["inspection_count"] / sum_df["annotation_count"]
-        sum_df["inspection_count/input_data_count"] = sum_df["inspection_count"] / sum_df["annotation_count"]
+        sum_df["inspection_comment_count/annotation_count"] = (
+            sum_df["inspection_comment_count"] / sum_df["annotation_count"]
+        )
+        sum_df["inspection_comment_count/input_data_count"] = (
+            sum_df["inspection_comment_count"] / sum_df["annotation_count"]
+        )
 
-        return AnnotatorProductivityPerDate(sum_df)
+        return cls(sum_df)
 
     @staticmethod
     def _get_df_sequential_date(df: pandas.DataFrame) -> pandas.DataFrame:
@@ -148,8 +152,8 @@ class AnnotatorProductivityPerDate(AbstractRoleProductivityPerDate):
                     "annotation_worktime_hour",
                     "inspection_worktime_hour",
                     "acceptance_worktime_hour",
-                    "sum_worktime_hour",
-                    "inspection_count",
+                    "worktime_hour",
+                    "inspection_comment_count",
                     "task_count",
                     "input_data_count",
                     "annotation_count",
@@ -212,12 +216,12 @@ class AnnotatorProductivityPerDate(AbstractRoleProductivityPerDate):
             ),
             dict(
                 title="教師付開始日ごとのアノテーションあたり検査コメント数",
-                y_column_name="inspection_count/annotation_count",
+                y_column_name="inspection_comment_count/annotation_count",
                 y_axis_label="アノテーションあたり検査コメント数",
             ),
             dict(
                 title="教師付開始日ごとのアノテーションあたり検査コメント数(1週間移動平均)",
-                y_column_name=f"inspection_count/annotation_count{WEEKLY_MOVING_AVERAGE_COLUMN_SUFFIX}",
+                y_column_name=f"inspection_comment_count/annotation_count{WEEKLY_MOVING_AVERAGE_COLUMN_SUFFIX}",
                 y_axis_label="アノテーションあたり検査コメント数",
             ),
         ]
@@ -252,9 +256,9 @@ class AnnotatorProductivityPerDate(AbstractRoleProductivityPerDate):
                 * 60
                 / get_weekly_sum(df_subset["annotation_count"])
             )
-            df_subset[f"inspection_count/annotation_count{WEEKLY_MOVING_AVERAGE_COLUMN_SUFFIX}"] = get_weekly_sum(
-                df_subset["inspection_count"]
-            ) / get_weekly_sum(df_subset["annotation_count"])
+            df_subset[
+                f"inspection_comment_count/annotation_count{WEEKLY_MOVING_AVERAGE_COLUMN_SUFFIX}"
+            ] = get_weekly_sum(df_subset["inspection_comment_count"]) / get_weekly_sum(df_subset["annotation_count"])
 
             source = ColumnDataSource(data=df_subset)
             color = get_color_from_palette(user_index)
@@ -291,7 +295,7 @@ class AnnotatorProductivityPerDate(AbstractRoleProductivityPerDate):
                 "task_count",
                 "input_data_count",
                 "annotation_count",
-                "inspection_count",
+                "inspection_comment_count",
             ]
         )
         for fig in figs:
@@ -344,12 +348,12 @@ class AnnotatorProductivityPerDate(AbstractRoleProductivityPerDate):
             ),
             dict(
                 title="教師付開始日ごとの入力データあたり検査コメント数",
-                y_column_name="inspection_count/input_data_count",
+                y_column_name="inspection_comment_count/input_data_count",
                 y_axis_label="入力データあたり検査コメント数",
             ),
             dict(
                 title="教師付開始日ごとの入力データあたり検査コメント数(1週間移動平均)",
-                y_column_name=f"inspection_count/input_data_count{WEEKLY_MOVING_AVERAGE_COLUMN_SUFFIX}",
+                y_column_name=f"inspection_comment_count/input_data_count{WEEKLY_MOVING_AVERAGE_COLUMN_SUFFIX}",
                 y_axis_label="入力データあたり検査コメント数",
             ),
         ]
@@ -385,9 +389,9 @@ class AnnotatorProductivityPerDate(AbstractRoleProductivityPerDate):
                 * 60
                 / get_weekly_sum(df_subset["input_data_count"])
             )
-            df_subset[f"inspection_count/input_data_count{WEEKLY_MOVING_AVERAGE_COLUMN_SUFFIX}"] = get_weekly_sum(
-                df_subset["inspection_count"]
-            ) / get_weekly_sum(df_subset["input_data_count"])
+            df_subset[
+                f"inspection_comment_count/input_data_count{WEEKLY_MOVING_AVERAGE_COLUMN_SUFFIX}"
+            ] = get_weekly_sum(df_subset["inspection_comment_count"]) / get_weekly_sum(df_subset["input_data_count"])
 
             source = ColumnDataSource(data=df_subset)
             color = get_color_from_palette(user_index)
@@ -424,7 +428,7 @@ class AnnotatorProductivityPerDate(AbstractRoleProductivityPerDate):
                 "task_count",
                 "input_data_count",
                 "annotation_count",
-                "inspection_count",
+                "inspection_comment_count",
             ]
         )
         for fig in figs:
@@ -434,10 +438,6 @@ class AnnotatorProductivityPerDate(AbstractRoleProductivityPerDate):
         write_bokeh_graph(bokeh.layouts.column(figs), output_file)
 
     def to_csv(self, output_file: Path) -> None:
-        """
-        日毎の全体の生産量、生産性を出力する。
-
-        """
 
         if not self._validate_df_for_output(output_file):
             return
@@ -449,8 +449,8 @@ class AnnotatorProductivityPerDate(AbstractRoleProductivityPerDate):
             "task_count",
             "input_data_count",
             "annotation_count",
-            "inspection_count",
-            "sum_worktime_hour",
+            "inspection_comment_count",
+            "worktime_hour",
             "annotation_worktime_hour",
             "inspection_worktime_hour",
             "acceptance_worktime_hour",
@@ -465,17 +465,17 @@ class AnnotatorProductivityPerDate(AbstractRoleProductivityPerDate):
         columns = (
             production_columns
             + velocity_columns
-            + ["inspection_count/input_data_count", "inspection_count/annotation_count"]
+            + ["inspection_comment_count/input_data_count", "inspection_comment_count/annotation_count"]
         )
 
         print_csv(self.df[columns], output=str(output_file))
 
 
-class InspectorProductivityPerDate(AbstractRoleProductivityPerDate):
+class InspectorProductivityPerDate(AbstractPhaseProductivityPerDate):
     """検査開始日ごとの検査者の生産性に関する情報"""
 
-    @staticmethod
-    def from_df_task(df_task: pandas.DataFrame) -> InspectorProductivityPerDate:
+    @classmethod
+    def from_df_task(cls, df_task: pandas.DataFrame) -> InspectorProductivityPerDate:
         """
         検査開始日ごとの受入者の生産性に関するDataFrameを生成する。
 
@@ -514,7 +514,7 @@ class InspectorProductivityPerDate(AbstractRoleProductivityPerDate):
             sum_df["inspection_worktime_hour"] / sum_df["input_data_count"]
         )
 
-        return InspectorProductivityPerDate(sum_df)
+        return cls(sum_df)
 
     @staticmethod
     def _get_df_sequential_date(df: pandas.DataFrame) -> pandas.DataFrame:
@@ -782,7 +782,7 @@ class InspectorProductivityPerDate(AbstractRoleProductivityPerDate):
                 "task_count",
                 "input_data_count",
                 "annotation_count",
-                "inspection_count",
+                "inspection_comment_count",
             ]
         )
         for fig in figs:
@@ -818,11 +818,11 @@ class InspectorProductivityPerDate(AbstractRoleProductivityPerDate):
         print_csv(self.df[columns], output=str(output_file))
 
 
-class AcceptorProductivityPerDate(AbstractRoleProductivityPerDate):
+class AcceptorProductivityPerDate(AbstractPhaseProductivityPerDate):
     """受入開始日ごとの受入者の生産性に関する情報"""
 
-    @staticmethod
-    def from_df_task(df_task: pandas.DataFrame) -> AcceptorProductivityPerDate:
+    @classmethod
+    def from_df_task(cls, df_task: pandas.DataFrame) -> AcceptorProductivityPerDate:
         """
         受入開始日ごとの受入者の生産性に関するDataFrameを生成する。
 
@@ -1130,7 +1130,7 @@ class AcceptorProductivityPerDate(AbstractRoleProductivityPerDate):
                 "task_count",
                 "input_data_count",
                 "annotation_count",
-                "inspection_count",
+                "inspection_comment_count",
             ]
         )
         for fig in figs:
