@@ -1,7 +1,9 @@
 import argparse
+from typing import Optional
 
 import annofabcli
 import annofabcli.common.cli
+import annofabcli.task_history.download_task_history_json
 import annofabcli.task_history.list_task_history
 import annofabcli.task_history.list_task_history_with_json
 
@@ -11,11 +13,12 @@ def parse_args(parser: argparse.ArgumentParser):
     subparsers = parser.add_subparsers(dest="subcommand_name")
 
     # サブコマンドの定義
+    annofabcli.task_history.download_task_history_json.add_parser(subparsers)
     annofabcli.task_history.list_task_history.add_parser(subparsers)
     annofabcli.task_history.list_task_history_with_json.add_parser(subparsers)
 
 
-def add_parser(subparsers: argparse._SubParsersAction):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
     subcommand_name = "task_history"
     subcommand_help = "タスク履歴関係のサブコマンド"
     description = "タスク履歴関係のサブコマンド"
@@ -24,3 +27,4 @@ def add_parser(subparsers: argparse._SubParsersAction):
         subparsers, subcommand_name, subcommand_help, description, is_subcommand=False
     )
     parse_args(parser)
+    return parser
